@@ -5,9 +5,12 @@ function(object,
   ans <- list()
   ans$pscale <- z$pscale	
   ans$sigma <- z$sigma
-  ans$logLik <- logLik(z$obj)[1]	
+  ans$logLik <- logLik(z)[1]	
   ans$link <- z$link
+  ans$method <- z$method
+  ans$par <- z$par
   ans$model <- z$model
+  ans$formula <- z$formula
   class(ans) <- "summary.mlcm"
   ans
 }
